bugReport: File an RStudio Bug Report

View source: R/bug-report.R

bugReportR Documentation

File an RStudio Bug Report

Description

A utility function to assist with the filing of an RStudio bug report. This function will pre-populate a template with information useful in understanding your reported bug.

Usage

bugReport()

rstudioapi documentation built on June 12, 2026, 1:06 a.m.